Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1BitmapMemoryUsageMetricSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

Singleton resource representing the set of Bitmap Memory Usage metrics. This metric set contains bitmap memory usage data combined with usage data. ** Supported aggregation periods:** * DAILY: metrics are aggregated in calendar date intervals. Due to historical constraints, the only supported timezone is America/Los_Angeles. Supported metrics: * bitmapMemoryUsageP50 (google. type.Decimal): 50th percentile of bitmap memory usage. * bitmapMemoryUsageP75 (google.type.Decimal): 75th percentile of bitmap memory usage. * bitmapMemoryUsageP90 (google.type.Decimal): 90th percentile of bitmap memory usage. * bitmapMemoryUsageP95 (google.type. Decimal): 95th percentile of bitmap memory usage. * bitmapMemoryUsageP99 ( google.type.Decimal): 99th percentile of bitmap memory usage. * distinctUsers (google.type.Decimal): Count of distinct users for which memory metrics were reported during the aggregation period. Care must be taken not to aggregate this count further, as it may result in users being counted multiple times. The value is rounded to the nearest multiple of 10, 100, 1,000 or 1,000,000, depending on the magnitude of the value. *Supported dimensions:

  • * apiLevel (string): the API level of Android that was running on the user' s device, e.g., 26. * versionCode (int64): version of the app that was running on the user's device. * deviceModel (string): unique identifier of the user's device model. The form of the identifier is 'deviceBrand/device', where deviceBrand corresponds to Build.BRAND and device corresponds to Build. DEVICE, e.g., google/coral. * deviceBrand (string): unique identifier of the user's device brand, e.g., google. * deviceType (string): the type (also known as form factor) of the user's device, e.g., PHONE. * countryCode ( string): the country or region of the user's device based on their IP address, represented as a 2-letter ISO-3166 code (e.g. US for the United States). * deviceRamBucket (int64): RAM of the device, in MB, in buckets (3GB, 4GB, etc.) . * deviceSocMake (string): Make of the device's primary system-on-chip, e.g. , Samsung. * deviceSocModel (string): Model of the device's primary system- on-chip, e.g., "Exynos 2100". * deviceCpuMake (string): Make of the device's CPU, e.g., Qualcomm. * deviceCpuModel (string): Model of the device's CPU, e. g., "Kryo 240". * deviceGpuMake (string): Make of the device's GPU, e.g., ARM. * deviceGpuModel (string): Model of the device's GPU, e.g., Mali. * deviceGpuVersion (string): Version of the device's GPU, e.g., T750. * deviceVulkanVersion (string): Vulkan version of the device, e.g., "4198400". * deviceGlEsVersion (string): OpenGL ES version of the device, e.g., "196610".
  • deviceScreenSize (string): Screen size of the device, e.g., NORMAL, LARGE.
  • deviceScreenDpi (string): Screen density of the device, e.g., mdpi, hdpi.
  • processName (string): the name of the process that was running, e.g., com. example.app. * appState (string): the state of the app when memory was collected, e.g., FOREGROUND. Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1BitmapMemoryUsageMetricSet

Returns a new instance of GooglePlayDeveloperReportingV1alpha1BitmapMemoryUsageMetricSet.



420
421
422
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#freshness_infoGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo

Represents the latest available time that can be requested in a TimelineSpec. Different aggregation periods have different freshness. For example, DAILY aggregation may lag behind HOURLY in cases where such aggregation is computed only once at the end of the day. Corresponds to the JSON property freshnessInfo



413
414
415
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 413

def freshness_info
  @freshness_info
end

#nameString

Identifier. The resource name. Format: apps/app/bitmapMemoryUsageMetricSet Corresponds to the JSON property name

Returns:

  • (String)


418
419
420
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 418

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



425
426
427
428
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 425

def update!(**args)
  @freshness_info = args[:freshness_info] if args.key?(:freshness_info)
  @name = args[:name] if args.key?(:name)
end