Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1ErrorIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

A group of related ErrorReports received for an app. Similar error reports are grouped together into issues with a likely identical root cause. Please note: ** this resource is currently in Alpha. There could be changes to the issue grouping that would result in similar but more recent error reports being assigned to different issues. This could also cause some issues disappearing entirely and being replaced by new ones. **Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1ErrorIssue

Returns a new instance of GooglePlayDeveloperReportingV1alpha1ErrorIssue.



819
820
821
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsArray<Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1IssueAnnotation>

List of annotations for an issue. Annotations provide additional information that may help in diagnosing and fixing the issue. Corresponds to the JSON property annotations



733
734
735
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 733

def annotations
  @annotations
end

#causeString

Cause of the issue. Depending on the type this can be either: * APPLICATION_NOT_RESPONDING: the type of ANR that occurred, e.g., 'Input dispatching timed out'. * CRASH: for Java unhandled exception errors, the type of the innermost exception that was thrown, e.g., IllegalArgumentException. For signals in native code, the signal that was raised, e.g. SIGSEGV. Corresponds to the JSON property cause

Returns:

  • (String)


742
743
744
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 742

def cause
  @cause
end

#distinct_usersFixnum

An estimate of the number of unique users who have experienced this issue ( only considering occurrences matching the filters and within the requested time period). Corresponds to the JSON property distinctUsers

Returns:

  • (Fixnum)


749
750
751
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 749

def distinct_users
  @distinct_users
end

#distinct_users_percentGoogle::Apis::PlaydeveloperreportingV1alpha1::GoogleTypeDecimal

A representation of a decimal value, such as 2.5. Clients may convert values into language-native decimal formats, such as Java's BigDecimal or Python's decimal.Decimal. Corresponds to the JSON property distinctUsersPercent



757
758
759
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 757

def distinct_users_percent
  @distinct_users_percent
end

#error_report_countFixnum

The total number of error reports in this issue (only considering occurrences matching the filters and within the requested time period). Corresponds to the JSON property errorReportCount

Returns:

  • (Fixnum)


763
764
765
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 763

def error_report_count
  @error_report_count
end

#first_app_versionGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1AppVersion

Representations of an app version. Corresponds to the JSON property firstAppVersion



768
769
770
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 768

def first_app_version
  @first_app_version
end

#first_os_versionGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1OsVersion

Representation of an OS version. Corresponds to the JSON property firstOsVersion



773
774
775
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 773

def first_os_version
  @first_os_version
end

#issue_uriString

Link to the issue in Android vitals in the Play Console. Corresponds to the JSON property issueUri

Returns:

  • (String)


778
779
780
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 778

def issue_uri
  @issue_uri
end

#last_app_versionGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1AppVersion

Representations of an app version. Corresponds to the JSON property lastAppVersion



783
784
785
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 783

def last_app_version
  @last_app_version
end

#last_error_report_timeString

Start of the hour during which the last error report in this issue occurred. Corresponds to the JSON property lastErrorReportTime

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 788

def last_error_report_time
  @last_error_report_time
end

#last_os_versionGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1OsVersion

Representation of an OS version. Corresponds to the JSON property lastOsVersion



793
794
795
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 793

def last_os_version
  @last_os_version
end

#locationString

Location where the issue happened. Depending on the type this can be either: * APPLICATION_NOT_RESPONDING: the name of the activity or service that stopped responding. * CRASH: the likely method name that caused the error. Corresponds to the JSON property location

Returns:

  • (String)


800
801
802
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 800

def location
  @location
end

#nameString

Identifier. The resource name of the issue. Format: apps/app/issue Corresponds to the JSON property name

Returns:

  • (String)


805
806
807
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 805

def name
  @name
end

#sample_error_reportsArray<String>

Output only. Sample error reports which belong to this ErrorIssue. Note: currently a maximum of 1 per ErrorIssue is supported. Format: "apps/app/ report" Corresponds to the JSON property sampleErrorReports

Returns:

  • (Array<String>)


812
813
814
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 812

def sample_error_reports
  @sample_error_reports
end

#typeString

Type of the errors grouped in this issue. Corresponds to the JSON property type

Returns:

  • (String)


817
818
819
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 817

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 824

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @cause = args[:cause] if args.key?(:cause)
  @distinct_users = args[:distinct_users] if args.key?(:distinct_users)
  @distinct_users_percent = args[:distinct_users_percent] if args.key?(:distinct_users_percent)
  @error_report_count = args[:error_report_count] if args.key?(:error_report_count)
  @first_app_version = args[:first_app_version] if args.key?(:first_app_version)
  @first_os_version = args[:first_os_version] if args.key?(:first_os_version)
  @issue_uri = args[:issue_uri] if args.key?(:issue_uri)
  @last_app_version = args[:last_app_version] if args.key?(:last_app_version)
  @last_error_report_time = args[:last_error_report_time] if args.key?(:last_error_report_time)
  @last_os_version = args[:last_os_version] if args.key?(:last_os_version)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @sample_error_reports = args[:sample_error_reports] if args.key?(:sample_error_reports)
  @type = args[:type] if args.key?(:type)
end