Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

Represents the latest available time that can be requested in a TimelineSpec. Different aggregation periods have different freshness. For example, DAILY aggregation may lag behind HOURLY in cases where such aggregation is computed only once at the end of the day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1FreshnessInfo

Returns a new instance of GooglePlayDeveloperReportingV1alpha1FreshnessInfo.



839
840
841
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#freshnessesArray<Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfoFreshness>

Information about data freshness for every supported aggregation period. This field has set semantics, keyed by the aggregation_period field. Corresponds to the JSON property freshnesses



837
838
839
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 837

def freshnesses
  @freshnesses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



844
845
846
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 844

def update!(**args)
  @freshnesses = args[:freshnesses] if args.key?(:freshnesses)
end