Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb
Overview
Singleton resource representing the set of LMK (Low Memory Kill) metrics. This
metric set contains LMKs data combined with usage data to produce a normalized
metric independent of user counts. Supported aggregation periods: * DAILY:
metrics are aggregated in calendar date intervals. Due to historical
constraints, the only supported timezone is America/Los_Angeles. Supported
metrics: * userPerceivedLmkRate (google.type.Decimal): Percentage of
distinct users in the aggregation period that experienced at least one LMK
while they were actively using your app (a user-perceived LMK). An app is
considered to be in active use if it is displaying any activity or executing
any foreground service. * userPerceivedLmkRate7dUserWeighted (google.type.
Decimal): Rolling average value of userPerceivedLmkRate in the last 7 days.
The daily values are weighted by the count of distinct users for the day. *
userPerceivedLmkRate28dUserWeighted (google.type.Decimal): Rolling average
value of userPerceivedLmkRate in the last 28 days. The daily values are
weighted by the count of distinct users for the day. * distinctUsers (
google.type.Decimal): Count of distinct users in the aggregation period that
were used as normalization value for the userPerceivedLmkRate metrics. A
user is counted in this metric if they used the app in the foreground during
the aggregation period. Care must be taken not to aggregate this count further,
as it may result in users being counted multiple times. The value is rounded
to the nearest multiple of 10, 100, 1,000 or 1,000,000, depending on the
magnitude of the value. Supported dimensions: * apiLevel (string): the
API level of Android that was running on the user's device, e.g., 26. *
versionCode (int64): version of the app that was running on the user's device.
deviceModel(string): unique identifier of the user's device model. The form of the identifier is 'deviceBrand/device', where deviceBrand corresponds to Build.BRAND and device corresponds to Build.DEVICE, e.g., google/coral. *deviceBrand(string): unique identifier of the user's device brand, e.g., google. *deviceType(string): the type (also known as form factor) of the user's device, e.g., PHONE. *countryCode(string): the country or region of the user's device based on their IP address, represented as a 2-letter ISO- 3166 code (e.g. US for the United States). *deviceRamBucket(int64): RAM of the device, in MB, in buckets (3GB, 4GB, etc.). *deviceSocMake(string): Make of the device's primary system-on-chip, e.g., Samsung. Reference *deviceSocModel(string): Model of the device's primary system-on-chip, e.g., " Exynos 2100". Reference *deviceCpuMake(string): Make of the device's CPU, e.g., Qualcomm. *deviceCpuModel(string): Model of the device's CPU, e.g., "Kryo 240". *deviceGpuMake(string): Make of the device's GPU, e.g., ARM. *deviceGpuModel(string): Model of the device's GPU, e.g., Mali. *deviceGpuVersion(string): Version of the device's GPU, e.g., T750. *deviceVulkanVersion(string): Vulkan version of the device, e.g., "4198400". *deviceGlEsVersion(string): OpenGL ES version of the device, e.g., "196610".deviceScreenSize(string): Screen size of the device, e.g., NORMAL, LARGE.deviceScreenDpi(string): Screen density of the device, e.g., mdpi, hdpi. Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app. Related metric sets: * vitals.errors contains normalized metrics about crashes, another stability metric. * vitals.errors contains normalized metrics about ANRs, another stability metric.
Instance Attribute Summary collapse
-
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet
constructor
A new instance of GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet
Returns a new instance of GooglePlayDeveloperReportingV1alpha1LmkRateMetricSet.
1011 1012 1013 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
Different aggregation periods have different freshness. For example, DAILY
aggregation may lag behind HOURLY in cases where such aggregation is
computed only once at the end of the day.
Corresponds to the JSON property freshnessInfo
1004 1005 1006 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1004 def freshness_info @freshness_info end |
#name ⇒ String
Identifier. The resource name. Format: apps/app/lmkRateMetricSet
Corresponds to the JSON property name
1009 1010 1011 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1009 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1016 1017 1018 1019 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1016 def update!(**args) @freshness_info = args[:freshness_info] if args.key?(:freshness_info) @name = args[:name] if args.key?(:name) end |