Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1MetricsRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

Represents a row of dimensions and metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1MetricsRow

Returns a new instance of GooglePlayDeveloperReportingV1alpha1MetricsRow.



1093
1094
1095
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_periodString

Optional. Granularity of the aggregation period of the row. Corresponds to the JSON property aggregationPeriod

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1063

def aggregation_period
  @aggregation_period
end

#dimensionsArray<Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1DimensionValue>

Optional. Dimension columns in the row. Corresponds to the JSON property dimensions



1068
1069
1070
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1068

def dimensions
  @dimensions
end

#metricsArray<Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1MetricValue>

Optional. Metric columns in the row. Corresponds to the JSON property metrics



1073
1074
1075
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1073

def metrics
  @metrics
end

#start_timeGoogle::Apis::PlaydeveloperreportingV1alpha1::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property startTime



1091
1092
1093
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1091

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1098
1099
1100
1101
1102
1103
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1098

def update!(**args)
  @aggregation_period = args[:aggregation_period] if args.key?(:aggregation_period)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @metrics = args[:metrics] if args.key?(:metrics)
  @start_time = args[:start_time] if args.key?(:start_time)
end