Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1QueryAnonRssAndSwapMemoryUsageMetricSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

Request message for QueryAnonRssAndSwapMemoryUsageMetricSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1QueryAnonRssAndSwapMemoryUsageMetricSetRequest

Returns a new instance of GooglePlayDeveloperReportingV1alpha1QueryAnonRssAndSwapMemoryUsageMetricSetRequest.



1394
1395
1396
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<String>

Optional. * Dimensions to slice the data by. Supported dimensions: * apiLevel (string): the API level of Android that was running on the user's device, e.g., 26. * versionCode (int64): version of the app that was running on the user's device. * deviceModel (string): unique identifier of the user' s device model. The form of the identifier is 'deviceBrand/device', where deviceBrand corresponds to Build.BRAND and device corresponds to Build.DEVICE, e.g., google/coral. * deviceBrand (string): unique identifier of the user's device brand, e.g., google. * deviceType (string): the type (also known as form factor) of the user's device, e.g., PHONE. * countryCode (string): the country or region of the user's device based on their IP address, represented as a 2-letter ISO-3166 code (e.g. US for the United States). * deviceRamBucket (int64): RAM of the device, in MB, in buckets (3GB, 4GB, etc.) . * deviceSocMake (string): Make of the device's primary system-on-chip, e.g. , Samsung. * deviceSocModel (string): Model of the device's primary system- on-chip, e.g., "Exynos 2100". * deviceCpuMake (string): Make of the device's CPU, e.g., Qualcomm. * deviceCpuModel (string): Model of the device's CPU, e. g., "Kryo 240". * deviceGpuMake (string): Make of the device's GPU, e.g., ARM. * deviceGpuModel (string): Model of the device's GPU, e.g., Mali. * deviceGpuVersion (string): Version of the device's GPU, e.g., T750. * deviceVulkanVersion (string): Vulkan version of the device, e.g., "4198400". * deviceGlEsVersion (string): OpenGL ES version of the device, e.g., "196610".

  • deviceScreenSize (string): Screen size of the device, e.g., NORMAL, LARGE.
  • deviceScreenDpi (string): Screen density of the device, e.g., mdpi, hdpi.
  • processName (string): the name of the process that was running, e.g., com. example.app. * appState (string): the state of the app when memory was collected, e.g., FOREGROUND. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


1330
1331
1332
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1330

def dimensions
  @dimensions
end

#filterString

Optional. * Filters to apply to data. The filtering expression follows AIP- 160 standard and supports filtering by equality of all breakdown dimensions. Corresponds to the JSON property filter

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1337

def filter
  @filter
end

#metricsArray<String>

Optional. * Metrics to aggregate. Supported metrics: * anonRssAndSwapMemoryUsageP50 (google.type.Decimal): 50th percentile of anon RSS and swap memory usage. * anonRssAndSwapMemoryUsageP75 (google.type. Decimal): 75th percentile of anon RSS and swap memory usage. * anonRssAndSwapMemoryUsageP90 (google.type.Decimal): 90th percentile of anon RSS and swap memory usage. * anonRssAndSwapMemoryUsageP95 (google.type. Decimal): 95th percentile of anon RSS and swap memory usage. * anonRssAndSwapMemoryUsageP99 (google.type.Decimal): 99th percentile of anon RSS and swap memory usage. * distinctUsers (google.type.Decimal): Count of distinct users for which memory metrics were reported during the aggregation period. Care must be taken not to aggregate this count further, as it may result in users being counted multiple times. The value is rounded to the nearest multiple of 10, 100, 1,000 or 1,000,000, depending on the magnitude of the value. Corresponds to the JSON property metrics

Returns:

  • (Array<String>)


1355
1356
1357
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1355

def metrics
  @metrics
end

#page_sizeFixnum

Optional. * Maximum size of the returned data. If unspecified, at most 1000 rows will be returned. The maximum value is 100000; values above 100000 will be coerced to 100000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1362
1363
1364
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1362

def page_size
  @page_size
end

#page_tokenString

Optional. * A page token, received from a previous call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to the request must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1369

def page_token
  @page_token
end

#timeline_specGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1TimelineSpec

Specification of the time-related aggregation parameters of a timeline. Timelines have an aggregation period (DAILY, HOURLY, etc) which defines how events are aggregated in metrics. The points in a timeline are defined by the starting DateTime of the aggregation period. The duration is implicit in the AggregationPeriod. Hourly aggregation periods, when supported by a metric set, are always specified in UTC to avoid ambiguities around daylight saving time transitions, where an hour is skipped when adopting DST, and repeated when abandoning DST. For example, the timestamp '2021-11-07 01:00:00 America/ Los_Angeles' is ambiguous since it can correspond to '2021-11-07 08:00:00 UTC' or '2021-11-07 09:00:00 UTC'. Daily aggregation periods require specifying a timezone which will determine the precise instants of the start and the end of the day. Not all metric sets support all timezones, so make sure to check which timezones are supported by the metric set you want to query. Corresponds to the JSON property timelineSpec



1386
1387
1388
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1386

def timeline_spec
  @timeline_spec
end

#user_cohortString

Optional. * User view to select. The output data will correspond to the selected view. The only supported value is OS_PUBLIC. Corresponds to the JSON property userCohort

Returns:

  • (String)


1392
1393
1394
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1392

def user_cohort
  @user_cohort
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1399
1400
1401
1402
1403
1404
1405
1406
1407
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1399

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @filter = args[:filter] if args.key?(:filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @timeline_spec = args[:timeline_spec] if args.key?(:timeline_spec)
  @user_cohort = args[:user_cohort] if args.key?(:user_cohort)
end