Class: Google::Apis::PlaydeveloperreportingV1alpha1::ApiservingMcpMcpToolDataHandlingProfile
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1alpha1::ApiservingMcpMcpToolDataHandlingProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb
Overview
Profile describing the data handling characteristics of an MCP tool. When used within the McpTool.meta field, this message should be packed into a google. protobuf.Any and associated with the key: "google.com/tool.profiles/ data_handling"
Instance Attribute Summary collapse
-
#input_data_access_level ⇒ String
// The data access level of the tool's inputs.
-
#output_data_access_level ⇒ String
The data access level of the tool's outputs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApiservingMcpMcpToolDataHandlingProfile
constructor
A new instance of ApiservingMcpMcpToolDataHandlingProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApiservingMcpMcpToolDataHandlingProfile
Returns a new instance of ApiservingMcpMcpToolDataHandlingProfile.
42 43 44 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 42 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_data_access_level ⇒ String
// The data access level of the tool's inputs.
Corresponds to the JSON property inputDataAccessLevel
35 36 37 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 35 def input_data_access_level @input_data_access_level end |
#output_data_access_level ⇒ String
The data access level of the tool's outputs.
Corresponds to the JSON property outputDataAccessLevel
40 41 42 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 40 def output_data_access_level @output_data_access_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47 48 49 50 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 47 def update!(**args) @input_data_access_level = args[:input_data_access_level] if args.key?(:input_data_access_level) @output_data_access_level = args[:output_data_access_level] if args.key?(:output_data_access_level) end |