Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb
Overview
Singleton resource representing the set of Anon RSS and Swap Memory Usage
metrics. This metric set contains anon RSS and swap memory usage data combined
with usage data. Supported aggregation periods: * DAILY: metrics are
aggregated in calendar date intervals. Due to historical constraints, the only
supported timezone is America/Los_Angeles. Supported metrics: *
anonRssAndSwapMemoryUsageP50 (google.type.Decimal): 50th percentile of anon
RSS and swap memory usage. * anonRssAndSwapMemoryUsageP75 (google.type.
Decimal): 75th percentile of anon RSS and swap memory usage. *
anonRssAndSwapMemoryUsageP90 (google.type.Decimal): 90th percentile of anon
RSS and swap memory usage. * anonRssAndSwapMemoryUsageP95 (google.type.
Decimal): 95th percentile of anon RSS and swap memory usage. *
anonRssAndSwapMemoryUsageP99 (google.type.Decimal): 99th percentile of anon
RSS and swap memory usage. * distinctUsers (google.type.Decimal): Count of
distinct users for which memory metrics were reported during the aggregation
period. Supported dimensions: * apiLevel (string): the API level of
Android that was running on the user's device, e.g., 26. * versionCode (
int64): version of the app that was running on the user's device. *
deviceModel (string): unique identifier of the user's device model. The form
of the identifier is 'deviceBrand/device', where deviceBrand corresponds to
Build.BRAND and device corresponds to Build.DEVICE, e.g., google/coral. *
deviceBrand (string): unique identifier of the user's device brand, e.g.,
google. * deviceType (string): the type (also known as form factor) of the
user's device, e.g., PHONE. * countryCode (string): the country or region of
the user's device based on their IP address, represented as a 2-letter ISO-
3166 code (e.g. US for the United States). * deviceRamBucket (int64): RAM of
the device, in MB, in buckets (3GB, 4GB, etc.). * deviceSocMake (string):
Make of the device's primary system-on-chip, e.g., Samsung. * deviceSocModel
(string): Model of the device's primary system-on-chip, e.g., "Exynos 2100". *
deviceCpuMake (string): Make of the device's CPU, e.g., Qualcomm. *
deviceCpuModel (string): Model of the device's CPU, e.g., "Kryo 240". *
deviceGpuMake (string): Make of the device's GPU, e.g., ARM. *
deviceGpuModel (string): Model of the device's GPU, e.g., Mali. *
deviceGpuVersion (string): Version of the device's GPU, e.g., T750. *
deviceVulkanVersion (string): Vulkan version of the device, e.g., "4198400". *
deviceGlEsVersion (string): OpenGL ES version of the device, e.g., "196610".
deviceScreenSize(string): Screen size of the device, e.g., NORMAL, LARGE.deviceScreenDpi(string): Screen density of the device, e.g., mdpi, hdpi.processName(string): the name of the process that was running, e.g., com. example.app. *appState(string): the state of the app when memory was collected, e.g., FOREGROUND. Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.
Instance Attribute Summary collapse
-
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet
constructor
A new instance of GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet
Returns a new instance of GooglePlayDeveloperReportingV1alpha1AnonRssAndSwapMemoryUsageMetricSet.
211 212 213 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
Different aggregation periods have different freshness. For example, DAILY
aggregation may lag behind HOURLY in cases where such aggregation is
computed only once at the end of the day.
Corresponds to the JSON property freshnessInfo
203 204 205 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 203 def freshness_info @freshness_info end |
#name ⇒ String
Identifier. * The resource name. Format: apps/app/
anonRssAndSwapMemoryUsageMetricSet
Corresponds to the JSON property name
209 210 211 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 209 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
216 217 218 219 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 216 def update!(**args) @freshness_info = args[:freshness_info] if args.key?(:freshness_info) @name = args[:name] if args.key?(:name) end |