Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb

Overview

Request message for QueryErrorCountMetricSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetRequest

Returns a new instance of GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetRequest.



1519
1520
1521
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<String>

Optional. Dimensions to slice the data by. Supported dimensions: * apiLevel (string): the API level of Android that was running on the user's device, e.g., 26. * versionCode (int64): unique identifier of the user's device model. The form of the identifier is 'deviceBrand/device', where deviceBrand corresponds to Build.BRAND and device corresponds to Build.DEVICE, e.g., google/coral. * deviceModel (string): unique identifier of the user's device model. * deviceType (string): identifier of the device's form factor, e.g., PHONE. * reportType (string): the type of error. The value should correspond to one of the possible values in ErrorType. * issueId (string): the id an error was assigned to. The value should correspond to the issue component of the issue name. * deviceRamBucket (int64): RAM of the device, in MB, in buckets (3GB, 4GB, etc.). * deviceSocMake (string): Make of the device's primary system-on-chip, e.g., Samsung. Reference * deviceSocModel ( string): Model of the device's primary system-on-chip, e.g., "Exynos 2100". Reference

  • deviceCpuMake (string): Make of the device's CPU, e.g., Qualcomm. * deviceCpuModel (string): Model of the device's CPU, e.g., "Kryo 240". * deviceGpuMake (string): Make of the device's GPU, e.g., ARM. * deviceGpuModel (string): Model of the device's GPU, e.g., Mali. * deviceGpuVersion (string): Version of the device's GPU, e.g., T750. * deviceVulkanVersion (string): Vulkan version of the device, e.g., "4198400". * deviceGlEsVersion (string): OpenGL ES version of the device, e.g., "196610".
  • deviceScreenSize (string): Screen size of the device, e.g., NORMAL, LARGE.
  • deviceScreenDpi (string): Screen density of the device, e.g., mdpi, hdpi. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


1468
1469
1470
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1468

def dimensions
  @dimensions
end

#filterString

Optional. Filters to apply to data. The filtering expression follows AIP-160 standard and supports filtering by equality of all breakdown dimensions and: * isUserPerceived (string): denotes whether error is user perceived or not, USER_PERCEIVED or NOT_USER_PERCEIVED. Corresponds to the JSON property filter

Returns:

  • (String)


1476
1477
1478
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1476

def filter
  @filter
end

#metricsArray<String>

Optional. Metrics to aggregate. Supported metrics: * errorReportCount ( google.type.Decimal): Absolute count of individual error reports that have been received for an app. * distinctUsers (google.type.Decimal): Count of distinct users for which reports have been received. Care must be taken not to aggregate this count further, as it may result in users being counted multiple times. This value is not rounded, however it may be an approximation. Corresponds to the JSON property metrics

Returns:

  • (Array<String>)


1486
1487
1488
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1486

def metrics
  @metrics
end

#page_sizeFixnum

Optional. Maximum size of the returned data. If unspecified, at most 1000 rows will be returned. The maximum value is 100000; values above 100000 will be coerced to 100000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1493
1494
1495
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1493

def page_size
  @page_size
end

#page_tokenString

Optional. A page token, received from a previous call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to the request must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


1500
1501
1502
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1500

def page_token
  @page_token
end

#timeline_specGoogle::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1TimelineSpec

Specification of the time-related aggregation parameters of a timeline. Timelines have an aggregation period (DAILY, HOURLY, etc) which defines how events are aggregated in metrics. The points in a timeline are defined by the starting DateTime of the aggregation period. The duration is implicit in the AggregationPeriod. Hourly aggregation periods, when supported by a metric set, are always specified in UTC to avoid ambiguities around daylight saving time transitions, where an hour is skipped when adopting DST, and repeated when abandoning DST. For example, the timestamp '2021-11-07 01:00:00 America/ Los_Angeles' is ambiguous since it can correspond to '2021-11-07 08:00:00 UTC' or '2021-11-07 09:00:00 UTC'. Daily aggregation periods require specifying a timezone which will determine the precise instants of the start and the end of the day. Not all metric sets support all timezones, so make sure to check which timezones are supported by the metric set you want to query. Corresponds to the JSON property timelineSpec



1517
1518
1519
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1517

def timeline_spec
  @timeline_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1524
1525
1526
1527
1528
1529
1530
1531
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1524

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @filter = args[:filter] if args.key?(:filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @timeline_spec = args[:timeline_spec] if args.key?(:timeline_spec)
end