Class: Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb,
lib/google/apis/playdeveloperreporting_v1alpha1/representations.rb
Overview
Request message for QuerySlowRenderingRateMetricSet.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<String>
Optional.
-
#filter ⇒ String
Optional.
-
#metrics ⇒ Array<String>
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#timeline_spec ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1TimelineSpec
Specification of the time-related aggregation parameters of a timeline.
-
#user_cohort ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest
constructor
A new instance of GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest
Returns a new instance of GooglePlayDeveloperReportingV1alpha1QuerySlowRenderingRateMetricSetRequest.
1952 1953 1954 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<String>
Optional. Dimensions to slice the data by. Supported dimensions: *
apiLevel (string): the API level of Android that was running on the user's
device, e.g., 26. * versionCode (int64): version of the app that was running
on the user's device. * deviceModel (string): unique identifier of the user'
s device model. The form of the identifier is 'deviceBrand/device', where
deviceBrand corresponds to Build.BRAND and device corresponds to Build.DEVICE,
e.g., google/coral. * deviceBrand (string): unique identifier of the user's
device brand, e.g., google. * deviceType (string): the type (also known as
form factor) of the user's device, e.g., PHONE. * countryCode (string): the
country or region of the user's device based on their IP address, represented
as a 2-letter ISO-3166 code (e.g. US for the United States). *
deviceRamBucket (int64): RAM of the device, in MB, in buckets (3GB, 4GB, etc.)
. * deviceSocMake (string): Make of the device's primary system-on-chip, e.g.
, Samsung. Reference * deviceSocModel (string): Model of the device's
primary system-on-chip, e.g., "Exynos 2100". Reference * deviceCpuMake (string):
Make of the device's CPU, e.g., Qualcomm. * deviceCpuModel (string): Model
of the device's CPU, e.g., "Kryo 240". * deviceGpuMake (string): Make of the
device's GPU, e.g., ARM. * deviceGpuModel (string): Model of the device's
GPU, e.g., Mali. * deviceGpuVersion (string): Version of the device's GPU, e.
g., T750. * deviceVulkanVersion (string): Vulkan version of the device, e.g.,
"4198400". * deviceGlEsVersion (string): OpenGL ES version of the device, e.
g., "196610". * deviceScreenSize (string): Screen size of the device, e.g.,
NORMAL, LARGE. * deviceScreenDpi (string): Screen density of the device, e.g.
, mdpi, hdpi.
Corresponds to the JSON property dimensions
1878 1879 1880 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1878 def dimensions @dimensions end |
#filter ⇒ String
Optional. Filters to apply to data. The filtering expression follows AIP-160 standard and supports filtering by equality of all
breakdown dimensions.
Corresponds to the JSON property filter
1885 1886 1887 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1885 def filter @filter end |
#metrics ⇒ Array<String>
Optional. Metrics to aggregate. Supported metrics: *
slowRenderingRate20Fps (google.type.Decimal): Percentage of distinct users
in the aggregation period that had a slow rendering. *
slowRenderingRate20Fps7dUserWeighted (google.type.Decimal): Rolling average
value of slowRenderingRate20Fps in the last 7 days. The daily values are
weighted by the count of distinct users for the day. *
slowRenderingRate20Fps28dUserWeighted (google.type.Decimal): Rolling
average value of slowRenderingRate20Fps in the last 28 days. The daily
values are weighted by the count of distinct users for the day. *
slowRenderingRate30Fps (google.type.Decimal): Percentage of distinct users
in the aggregation period that had a slow rendering. *
slowRenderingRate30Fps7dUserWeighted (google.type.Decimal): Rolling average
value of slowRenderingRate30Fps in the last 7 days. The daily values are
weighted by the count of distinct users for the day. *
slowRenderingRate30Fps28dUserWeighted (google.type.Decimal): Rolling
average value of slowRenderingRate30Fps in the last 28 days. The daily
values are weighted by the count of distinct users for the day. *
distinctUsers (google.type.Decimal): Count of distinct users in the
aggregation period that were used as normalization value for the
slowRenderingRate20Fps/slowRenderingRate30Fps metric. A user is counted in
this metric if their app was launched in the device. Care must be taken not to
aggregate this count further, as it may result in users being counted multiple
times. The value is rounded to the nearest multiple of 10, 100, 1,000 or 1,000,
000, depending on the magnitude of the value.
Corresponds to the JSON property metrics
1913 1914 1915 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1913 def metrics @metrics end |
#page_size ⇒ Fixnum
Optional. Maximum size of the returned data. If unspecified, at most 1000 rows
will be returned. The maximum value is 100000; values above 100000 will be
coerced to 100000.
Corresponds to the JSON property pageSize
1920 1921 1922 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1920 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous call. Provide this to
retrieve the subsequent page. When paginating, all other parameters provided
to the request must match the call that provided the page token.
Corresponds to the JSON property pageToken
1927 1928 1929 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1927 def page_token @page_token end |
#timeline_spec ⇒ Google::Apis::PlaydeveloperreportingV1alpha1::GooglePlayDeveloperReportingV1alpha1TimelineSpec
Specification of the time-related aggregation parameters of a timeline.
Timelines have an aggregation period (DAILY, HOURLY, etc) which defines
how events are aggregated in metrics. The points in a timeline are defined by
the starting DateTime of the aggregation period. The duration is implicit in
the AggregationPeriod. Hourly aggregation periods, when supported by a metric
set, are always specified in UTC to avoid ambiguities around daylight saving
time transitions, where an hour is skipped when adopting DST, and repeated
when abandoning DST. For example, the timestamp '2021-11-07 01:00:00 America/
Los_Angeles' is ambiguous since it can correspond to '2021-11-07 08:00:00 UTC'
or '2021-11-07 09:00:00 UTC'. Daily aggregation periods require specifying a
timezone which will determine the precise instants of the start and the end of
the day. Not all metric sets support all timezones, so make sure to check
which timezones are supported by the metric set you want to query.
Corresponds to the JSON property timelineSpec
1944 1945 1946 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1944 def timeline_spec @timeline_spec end |
#user_cohort ⇒ String
Optional. User view to select. The output data will correspond to the selected
view. The only supported value is OS_PUBLIC.
Corresponds to the JSON property userCohort
1950 1951 1952 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1950 def user_cohort @user_cohort end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/google/apis/playdeveloperreporting_v1alpha1/classes.rb', line 1957 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @filter = args[:filter] if args.key?(:filter) @metrics = args[:metrics] if args.key?(:metrics) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @timeline_spec = args[:timeline_spec] if args.key?(:timeline_spec) @user_cohort = args[:user_cohort] if args.key?(:user_cohort) end |